==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ar/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "المزيد من المعلومات",

    "audit_help" => "التحقق من هذا المربع سيؤدي إلى تعديل سجل الأصول لعكس هذا الموقع الجديد. تركه غير محدد سيلاحظ ببساطة الموقع في سجل المراجعة.<br><br>لاحظ أن هذا الأصل تم التحقق منه، فهو لن يغير موقع الشخص أو الأصل أو الموقع الذي يتم التحقق منه إليه.",

    'assets' => 'الأصول هي العناصر التي يتم تتبعها بواسطة الرقم التسلسلي أو ترميز الأصل. وهي تميل إلى أن تكون ممتلكات ذات قيمة أعلى حيث انه من المهم توثيقها.',

    'categories' => 'التصنيفات تساعدك على ترتيب الأصول. من الأمثلة على التصنيفات &quot; حواسيب مكتبية &quot;، &quot; حواسيب محمولة &quot;، &quot;الهواتف النقالة &quot;، &quot;أجهزة لوحية &quot; وهكذا، كما يمكنك استخدام التصنيفات بأي طريقة تناسبك.',

    'accessories' => 'الملحقات هي أي شيء تصدره للمستخدمين ولكن ليس لها رقم تسلسلي (أو لا تهتم بتعقبه بشكل فريد). على سبيل المثال، الفئران الحاسوبية أو لوحة المفاتيح.',

    'companies'     => 'يمكن استخدام الشركات كمجال بسيط لتحديد الهوية، أو يمكن استخدامها للحد من وضوح الأصول، المستخدمين، إلخ إذا تم تمكين دعم الشركة الكامل في إعدادات المشرف الخاص بك.',

    'components'    => 'المكونات هي عناصر تشكل جزءا من الأصل، مثل HDD، ذاكرة الوصول العشوائي، إلخ.',

    'consumables'   => 'المواد الاستهلاكية هي أي شيء يتم شراؤه وسيتم استخدامه مع مرور الوقت. على سبيل المثال حبر الطابعة أو ورق آلة النسخ.',

    'depreciations' => 'يمكنك إعداد استهلاك الأصول لاستهلاك الأصول بناء على الاستهلاك الثابت للقيمة.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ar/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'المزيد من المعلومات',

    'audit_help' => 'التحقق من هذا المربع سيؤدي إلى تعديل سجل الأصول لعكس هذا الموقع الجديد. تركه غير محدد سيلاحظ ببساطة الموقع في سجل المراجعة.<br><br>لاحظ أن هذا الأصل تم التحقق منه، فهو لن يغير موقع الشخص أو الأصل أو الموقع الذي يتم التحقق منه إليه.',

    'assets' => 'الأصول هي العناصر التي يتم تتبعها بواسطة الرقم التسلسلي أو ترميز الأصل. وهي تميل إلى أن تكون ممتلكات ذات قيمة أعلى حيث انه من المهم توثيقها.',

    'categories' => 'التصنيفات تساعدك على ترتيب الأصول. من الأمثلة على التصنيفات &quot; حواسيب مكتبية &quot;، &quot; حواسيب محمولة &quot;، &quot;الهواتف النقالة &quot;، &quot;أجهزة لوحية &quot; وهكذا، كما يمكنك استخدام التصنيفات بأي طريقة تناسبك.',

    'accessories' => 'الملحقات هي أي شيء تصدره للمستخدمين ولكن ليس لها رقم تسلسلي (أو لا تهتم بتعقبه بشكل فريد). على سبيل المثال، الفئران الحاسوبية أو لوحة المفاتيح.',

    'companies'     => 'يمكن استخدام الشركات كمجال بسيط لتحديد الهوية، أو يمكن استخدامها للحد من وضوح الأصول، المستخدمين، إلخ إذا تم تمكين دعم الشركة الكامل في إعدادات المشرف الخاص بك.',

    'components'    => 'المكونات هي عناصر تشكل جزءا من الأصل، مثل HDD، ذاكرة الوصول العشوائي، إلخ.',

    'consumables'   => 'المواد الاستهلاكية هي أي شيء يتم شراؤه وسيتم استخدامه مع مرور الوقت. على سبيل المثال حبر الطابعة أو ورق آلة النسخ.',

    'depreciations' => 'يمكنك إعداد استهلاك الأصول لاستهلاك الأصول بناء على الاستهلاك الثابت للقيمة.',

];
